gensim: corpora – Package for corpora I/O
Description: Efficient topic modelling of text semantics in Python.

#

- Home
- Tutorials
- Install
- Support
- API
- About

corpora – Package for corpora I/O

# `corpora` – Package for corpora I/O

This package contains implementations of various streaming corpus I/O format.

© Copyright 2009-2013, Radim Řehůřek
Last updated on Dec 26, 2013.

- Home
- |
- Tutorials
- |
- Install
- |
- Support
- |
- API
- |
- About

Tweet @RadimRehurek
Support:
Join the gensim discussion group